==> ZenTaoALM.12.4.2.int.zbox_old.64.tar.gz: zbox/app/zentaoep/module/feedback/lang/zh-cn.php <==
<?php
$lang->feedback->common       = '反馈';
$lang->feedback->module       = '所属分类';
$lang->feedback->moduleAB     = '分类';
$lang->feedback->manageCate   = '维护分类';
$lang->feedback->index        = '反馈首页';
$lang->feedback->create       = '创建反馈';
$lang->feedback->edit         = '编辑反馈';
$lang->feedback->createFaq    = '创建FAQ';
$lang->feedback->faq          = 'FAQ';
$lang->feedback->nonRDBrowse  = '非研发界面浏览';
$lang->feedback->browse       = '浏览反馈';
$lang->feedback->list         = '反馈列表';
$lang->feedback->header       = '问题反馈';
$lang->feedback->view         = '反馈详情';
$lang->feedback->review       = '评审';
$lang->feedback->reviewAction = '评审反馈';
$lang->feedback->adminView    = '研发页面反馈详情';
$lang->feedback->close        = '关闭';
$lang->feedback->closeAction  = '关闭反馈';
$lang->feedback->feelLike     = '等感觉很赞！';
$lang->feedback->ask          = '追问';
$lang->feedback->toStory      = '转' . $lang->storyCommon;
$lang->feedback->toTask       = '转任务';
$lang->feedback->toBug        = '转Bug';
$lang->feedback->toTodo       = '转待办';
$lang->feedback->story        = $lang->storyCommon . '信息';
$lang->feedback->bug          = 'Bug信息';
$lang->feedback->todo         = '待办信息';
$lang->feedback->task         = '任务信息';
$lang->feedback->reply        = '回复';
$lang->feedback->replyAction  = '回复反馈';
$lang->feedback->convert      = '转化';
$lang->feedback->assign       = '指派';
$lang->feedback->assignAction = '指派反馈';
$lang->feedback->export       = '导出';
$lang->feedback->exportAction = '导出反馈';
$lang->feedback->assignTo     = '指派';
$lang->feedback->mailto       = '抄送给';
$lang->feedback->delete       = '删除反馈';
$lang->feedback->mailNotify   = '接收邮件通知。';
$lang->feedback->search       = '搜索';
$lang->feedback->comment      = '评论';
$lang->feedback->products     = '权限';
$lang->feedback->batchEdit    = '批量编辑';
$lang->feedback->batchClose   = '批量关闭';
$lang->feedback->batchReview       = '批量评审';
$lang->feedback->batchAssignTo     = '批量指派';
$lang->feedback->batchChangeModule = '批量更改模块';
$lang->feedback->manageProduct     = '授权用户';

$lang->feedback->id             = '编号';
$lang->feedback->product        = '所属产品';
$lang->feedback->title          = '标题';
$lang->feedback->desc           = '描述';
$lang->feedback->status         = '状态';
$lang->feedback->subStatus      = '子状态';
$lang->feedback->openedBy       = '反馈人';
$lang->feedback->openedDate     = '反馈时间';
$lang->feedback->processedBy    = '由谁处理';
$lang->feedback->processedDate  = '处理时间';
$lang->feedback->reviewedBy     = '由谁评审';
$lang->feedback->reviewedDate   = '评审时间';
$lang->feedback->reviewResult   = '评审结果';
$lang->feedback->reviewedByAB   = '评审人';
$lang->feedback->reviewedDateAB = '日期';
$lang->feedback->reviewResultAB = '结果';
$lang->feedback->assignedTo     = '指派给';
$lang->feedback->assignedDate   = '指派时间';
$lang->feedback->closedBy       = '由谁关闭';
$lang->feedback->closedDate     = '关闭时间';
$lang->feedback->closedReason   = '关闭原因';
$lang->feedback->public         = '公开';
$lang->feedback->notify         = '通知';
$lang->feedback->likes          = '点赞人';
$lang->feedback->result         = '转化结果';
$lang->feedback->files          = '附件';
$lang->feedback->labelBasic     = '基本信息';
$lang->feedback->dept           = '部门';
$lang->feedback->editedBy       = '最后处理人';
$lang->feedback->editedDate     = '最后修改时间';
$lang->feedback->contactInfo    = '联系方式';
$lang->feedback->noAssigned     = '未指派';
$lang->feedback->deptManager    = '部门负责人';
$lang->feedback->reviewOpinion  = '评审意见';
$lang->feedback->deleted        = '已删除';

$lang->feedback->lblBasic   = '基本信息';
$lang->feedback->lblTrace   = '追溯关系图';
$lang->feedback->assigntome = '指派给我';
$lang->feedback->allProduct = '所有' . $lang->productCommon;

$lang->feedback->grantUser   = '授权用户';
$lang->feedback->noGrantUser = '非授权用户';
$lang->feedback->hasPrivUser = '注：可以创建反馈的用户默认有所有产品的权限，被分配权限后只有对应的产品权限。';

$lang->feedback->tabList['unclosed'] = '未关闭';
$lang->feedback->tabList['all']      = '全部';
$lang->feedback->tabList['public']   = '公开';

$lang->feedback->reviewResultList['']        = '';
$lang->feedback->reviewResultList['pass']    = '确认通过';
$lang->feedback->reviewResultList['clarify'] = '继续完善';

$lang->feedback->statusList['']           = '';
$lang->feedback->statusList['noreview']   = '待评审';
$lang->feedback->statusList['clarify']    = '待完善';
$lang->feedback->statusList['wait']       = '待处理';
$lang->feedback->statusList['commenting'] = '处理中';
$lang->feedback->statusList['replied']    = '已处理';
$lang->feedback->statusList['asked']      = '追问中';
$lang->feedback->statusList['tobug']      = '转Bug';
$lang->feedback->statusList['tostory']    = '转' . $lang->storyCommon;
$lang->feedback->statusList['totask']     = '转任务';
$lang->feedback->statusList['totodo']     = '转待办';
$lang->feedback->statusList['closed']     = '已关闭';

$lang->feedback->closedReasonList[]            = '';
$lang->feedback->closedReasonList['commented'] = '已处理';
$lang->feedback->closedReasonList['tobug']     = '转Bug';
$lang->feedback->closedReasonList['tostory']   = '转' . $lang->storyCommon;
$lang->feedback->closedReasonList['totask']    = '转任务';
$lang->feedback->closedReasonList['totodo']    = '转待办';
$lang->feedback->closedReasonList['repeat']    = '重复';
$lang->feedback->closedReasonList['refuse']    = '不予采纳';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = '不公开';
$lang->feedback->publicList['1'] = '公开';

$lang->feedback->confirmDelete = '是否删除该反馈？';
$lang->feedback->confirmClose  = '是否关闭该反馈？';

$lang->feedback->commented        = '$date, 由 <strong>$actor</strong> 添加评论。' . "\n";
$lang->feedback->noModule         = '<div>您现在还没有分类信息</div>';
$lang->feedback->mustChooseResult = '必须选择评审结果';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, 由 <strong>$actor</strong> 关闭，原因为 <strong>$extra</strong>。', 'extra' => 'closedReasonList');   
$lang->feedback->action->reviewed = array('main' => '$date, 由 <strong>$actor</strong> 记录评审结果，结果为 <strong>$extra</strong>。', 'extra' => 'reviewResultList');

==> ZenTaoALM.12.4.4.int.zbox_old.64.tar.gz: zbox/app/zentaoep/module/feedback/lang/zh-cn.php <==
<?php
$lang->feedback->common       = '反馈';
$lang->feedback->module       = '所属分类';
$lang->feedback->moduleAB     = '分类';
$lang->feedback->manageCate   = '维护分类';
$lang->feedback->index        = '反馈首页';
$lang->feedback->create       = '创建反馈';
$lang->feedback->edit         = '编辑反馈';
$lang->feedback->createFaq    = '创建FAQ';
$lang->feedback->faq          = 'FAQ';
$lang->feedback->nonRDBrowse  = '非研发界面浏览';
$lang->feedback->browse       = '浏览反馈';
$lang->feedback->list         = '反馈列表';
$lang->feedback->header       = '问题反馈';
$lang->feedback->view         = '反馈详情';
$lang->feedback->review       = '评审';
$lang->feedback->reviewAction = '评审反馈';
$lang->feedback->adminView    = '研发页面反馈详情';
$lang->feedback->close        = '关闭';
$lang->feedback->closeAction  = '关闭反馈';
$lang->feedback->feelLike     = '等感觉很赞！';
$lang->feedback->ask          = '追问';
$lang->feedback->toStory      = '转' . $lang->storyCommon;
$lang->feedback->toTask       = '转任务';
$lang->feedback->toBug        = '转Bug';
$lang->feedback->toTodo       = '转待办';
$lang->feedback->story        = $lang->storyCommon . '信息';
$lang->feedback->bug          = 'Bug信息';
$lang->feedback->todo         = '待办信息';
$lang->feedback->task         = '任务信息';
$lang->feedback->reply        = '回复';
$lang->feedback->replyAction  = '回复反馈';
$lang->feedback->convert      = '转化';
$lang->feedback->assign       = '指派';
$lang->feedback->assignAction = '指派反馈';
$lang->feedback->export       = '导出';
$lang->feedback->exportAction = '导出反馈';
$lang->feedback->assignTo     = '指派';
$lang->feedback->mailto       = '抄送给';
$lang->feedback->delete       = '删除反馈';
$lang->feedback->mailNotify   = '接收邮件通知。';
$lang->feedback->search       = '搜索';
$lang->feedback->comment      = '评论';
$lang->feedback->products     = '权限';
$lang->feedback->batchEdit    = '批量编辑';
$lang->feedback->batchClose   = '批量关闭';
$lang->feedback->batchReview       = '批量评审';
$lang->feedback->batchAssignTo     = '批量指派';
$lang->feedback->batchChangeModule = '批量更改模块';
$lang->feedback->manageProduct     = '授权用户';

$lang->feedback->id             = '编号';
$lang->feedback->product        = '所属' . $lang->productCommon;
$lang->feedback->title          = '标题';
$lang->feedback->desc           = '描述';
$lang->feedback->status         = '状态';
$lang->feedback->subStatus      = '子状态';
$lang->feedback->openedBy       = '反馈人';
$lang->feedback->openedDate     = '反馈时间';
$lang->feedback->processedBy    = '由谁处理';
$lang->feedback->processedDate  = '处理时间';
$lang->feedback->reviewedBy     = '由谁评审';
$lang->feedback->reviewedDate   = '评审时间';
$lang->feedback->reviewResult   = '评审结果';
$lang->feedback->reviewedByAB   = '评审人';
$lang->feedback->reviewedDateAB = '日期';
$lang->feedback->reviewResultAB = '结果';
$lang->feedback->assignedTo     = '指派给';
$lang->feedback->assignedDate   = '指派时间';
$lang->feedback->closedBy       = '由谁关闭';
$lang->feedback->closedDate     = '关闭时间';
$lang->feedback->closedReason   = '关闭原因';
$lang->feedback->public         = '公开';
$lang->feedback->notify         = '通知';
$lang->feedback->likes          = '点赞人';
$lang->feedback->result         = '转化结果';
$lang->feedback->files          = '附件';
$lang->feedback->labelBasic     = '基本信息';
$lang->feedback->dept           = '部门';
$lang->feedback->editedBy       = '最后处理人';
$lang->feedback->editedDate     = '最后修改时间';
$lang->feedback->contactInfo    = '联系方式';
$lang->feedback->noAssigned     = '未指派';
$lang->feedback->deptManager    = '部门负责人';
$lang->feedback->reviewOpinion  = '评审意见';
$lang->feedback->deleted        = '已删除';

$lang->feedback->lblBasic   = '基本信息';
$lang->feedback->lblTrace   = '追溯关系图';
$lang->feedback->assigntome = '指派给我';
$lang->feedback->allProduct = '所有' . $lang->productCommon;

$lang->feedback->grantUser   = '授权用户';
$lang->feedback->noGrantUser = '非授权用户';
$lang->feedback->hasPrivUser = '注：可以创建反馈的用户默认有所有产品的权限，被分配权限后只有对应的产品权限。';

$lang->feedback->tabList['unclosed'] = '未关闭';
$lang->feedback->tabList['all']      = '全部';
$lang->feedback->tabList['public']   = '公开';

$lang->feedback->reviewResultList['']        = '';
$lang->feedback->reviewResultList['pass']    = '确认通过';
$lang->feedback->reviewResultList['clarify'] = '继续完善';

$lang->feedback->statusList['']           = '';
$lang->feedback->statusList['noreview']   = '待评审';
$lang->feedback->statusList['clarify']    = '待完善';
$lang->feedback->statusList['wait']       = '待处理';
$lang->feedback->statusList['commenting'] = '处理中';
$lang->feedback->statusList['replied']    = '已处理';
$lang->feedback->statusList['asked']      = '追问中';
$lang->feedback->statusList['tobug']      = '转Bug';
$lang->feedback->statusList['tostory']    = '转' . $lang->storyCommon;
$lang->feedback->statusList['totask']     = '转任务';
$lang->feedback->statusList['totodo']     = '转待办';
$lang->feedback->statusList['closed']     = '已关闭';

$lang->feedback->closedReasonList[]            = '';
$lang->feedback->closedReasonList['commented'] = '已处理';
$lang->feedback->closedReasonList['tobug']     = '转Bug';
$lang->feedback->closedReasonList['tostory']   = '转' . $lang->storyCommon;
$lang->feedback->closedReasonList['totask']    = '转任务';
$lang->feedback->closedReasonList['totodo']    = '转待办';
$lang->feedback->closedReasonList['repeat']    = '重复';
$lang->feedback->closedReasonList['refuse']    = '不予采纳';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = '不公开';
$lang->feedback->publicList['1'] = '公开';

$lang->feedback->confirmDelete = '是否删除该反馈？';
$lang->feedback->confirmClose  = '是否关闭该反馈？';

$lang->feedback->commented        = '$date, 由 <strong>$actor</strong> 添加评论。' . "\n";
$lang->feedback->noModule         = '<div>您现在还没有分类信息</div>';
$lang->feedback->mustChooseResult = '必须选择评审结果';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, 由 <strong>$actor</strong> 关闭，原因为 <strong>$extra</strong>。', 'extra' => 'closedReasonList');   
$lang->feedback->action->reviewed = array('main' => '$date, 由 <strong>$actor</strong> 记录评审结果，结果为 <strong>$extra</strong>。', 'extra' => 'reviewResultList');
